########Nutrient Budget of the western Dutch Wadden Sea######
#This is an R script accompyning a study on nutrient budgets of the western Dutch Wadden Sea
#This script was written by: Alexa Sarina Jung
#Co-Authors: A.G. Brinkman, E.O. Folmer, P.M.J. Herman, H.W. van der Veer, C.J.M. Philippart
#Manuscript Title: Long-term trends in nutrient budgets of the western Dutch Wadden Sea (1976 - 2012)
#submitted to Journal of Sea Research
#the data file is available from: http://doi.org/10.4121/uuid:a7859369-e2c5-4070-bbbf-44611f468b2e


#load required packages
require(stringr)
require(reshape2)
require(lubridate)
require(plyr)
#define "not in" function
`%ni%` <- Negate(`%in%`)

#read data file, adjust path if neccessary
Budget<-read.csv("Budget-Base-data.csv", header=TRUE)
#set constant variables
Conv<-(24*60*60)/1000 #to convert from mmol/m3 and m3/sec to mol/day
K1<-3556  #Dispersive transport (tidal exchange)
Qt<-800 #tidally driven residual mass transport (from Ridderinkhof et. al 1990)

Surf<-1414500000 #surface area of the Western wadden Sea in m2
# North Sea to Vlie In
Budget$Q2<-Qt-Budget$Kornwerderzand/2 
#Total input from IJsselmeer& Vlie
Budget$Q1<-(Budget$DenOever+Budget$Kornwerderzand+Budget$Q2)*-1 

#calculations for P
Budget$IJsselOutP<-(Budget$DENOVR_AvgPmmol*Budget$DenOever*Conv)+(Budget$KORNWD_AvgPmmol*Budget$Kornwerderzand*Conv)
Budget$WWSthroughP<-Budget$Q2*Budget$VLIESM_AvgPmmol*Conv
Budget$dP<-Budget$CALLOG2_AvgPmmol-Budget$MARSDND_AvgPmmol
Budget$exchangeNSP<-Budget$dP*K1*Conv
Budget$WWSadvecP<-Budget$Q1*Budget$MARSDND_AvgPmmol*Conv
Budget$P_residual<-(Budget$IJsselOutP+Budget$WWSadvecP+Budget$WWSthroughP+Budget$exchangeNSP)*-1


#calculations for N
Budget$IJsselOutN<-(Budget$DENOVR_AvgNmmol*Budget$DenOever*Conv)+(Budget$KORNWD_AvgNmmol*Budget$Kornwerderzand*Conv)
Budget$WWSthroughN<-Budget$Q2*Budget$VLIESM_AvgNmmol*Conv
Budget$AtmosphereN<-0.19/1000*Surf
Budget$dN<-Budget$CALLOG2_AvgNmmol-Budget$MARSDND_AvgNmmol
Budget$exchangeNSN<-Budget$dN*K1*Conv
Budget$WWSadvecN<-Budget$Q1*Budget$MARSDND_AvgNmmol*Conv
Budget$N_residual1<-Budget$P_residual*Budget$MARSDND_NP
Budget$N_residual2<-(Budget$IJsselOutN+Budget$AtmosphereN+Budget$WWSadvecN+Budget$WWSthroughN+Budget$exchangeNSN+Budget$N_residual1)*-1
Budget$N_residual3<-(Budget$IJsselOutN+Budget$WWSadvecN+Budget$WWSthroughN+Budget$exchangeNSN+Budget$AtmosphereN)*-1

Budget$Date<-ymd(str_c(as.character(Budget$Year),as.character(Budget$Index),"1",sep="-"))
